@@ -95,7 +95,7 @@ class FBetaScoreWithLogits(FBetaScore):
             beta=beta,
             threshold=thresholds,
             name=name,
-            dtype=dtype
+            dtype=dtype,
         )
         self.logits2scores = logits2scores
         if logits2scores == "sigmoid":
@@ -112,4 +112,10 @@ class FBetaScoreWithLogits(FBetaScore):
         super().update_state(y_true, self._l2s(y_logits), sample_weight=sample_weight)
 
     def get_config(self) -> Dict[str, Any]:
-        return {**super().get_config(), "logits2scores": self.logits2scores}
\ No newline at end of file
+        configs = super().get_config()
+        configs.pop("threshold", None)
+        return {
+            **configs,
+            "logits2scores": self.logits2scores,
+            "thresholds": self.threshold,
+        }
