@@ -50,16 +50,16 @@ class DeepClassifier(SupervisedNLPModel):
     def is_multilabel(self):
         return self._is_multilabel
 
-    def get_loss(self):
+    def get_loss(self, *args, **kwargs):
         if self.is_multilabel:
             return tf.keras.losses.BinaryCrossentropy(from_logits=True)
         else:
             return tf.keras.losses.CategoricalCrossentropy(from_logits=True)
 
-    def get_callbacks(self) -> List[tf.keras.callbacks.Callback]:
+    def get_callbacks(self, *args, **kwargs) -> List[tf.keras.callbacks.Callback]:
         return []
 
-    def get_metrics(self) -> List[tf.keras.metrics.Metric]:
+    def get_metrics(self, *args, **kwargs) -> List[tf.keras.metrics.Metric]:
         if self.is_multilabel:
             return [
                 PrecisionWithLogits(),
@@ -125,12 +125,16 @@ class DeepClassifier(SupervisedNLPModel):
         X: Sequence[str] = None,
         y: Union[Sequence[Sequence[str]], Sequence[str]] = None,
         *,
+        dataset: ClassificationDataset = None,
         thresholds: Union[float, List[float]] = 0.5,
         batch_size: int = 128
     ) -> pd.DataFrame:
-        predictions = self.predict(X=X, thresholds=thresholds, batch_size=batch_size)
+        dataset = self.prepare_dataset(X, y, dataset)
+        predictions = self.predict(
+            dataset=dataset, thresholds=thresholds, batch_size=batch_size
+        )
         return classification_fscore(
-            y, predictions, self.is_multilabel, classes=self.classes
+            dataset.label, predictions, self.is_multilabel, classes=self.classes
         )
 
     def format_score(self, score_df: pd.DataFrame, format: str = "markdown") -> str:
