@@ -28,8 +28,7 @@ class BertTagger(DeepTagger):
         num_fc_layers: int = 2,
         fc_hidden_size: int = 256,
         output_dropout: float = 0.5,
-        text2vec: Optional[Bert2vec] = None,
-        **kwargs
+        text2vec: Optional[Bert2vec] = None, **kwargs
     ) -> None:
         super().__init__(
             classes,
